@@ -577,7 +577,7 @@ class DataTransform(forms.ModelForm):
                 )
 
         except Exception as e:
-            print(str(e.with_traceback()))
+            print(str(e))
 
         self.nested_constants_form = DataConstantsTransformerInlineFormset(
             instance=self.instance,
